Documentation
¶
Index ¶
Constants ¶
const ( DefaultNetwork = "tcp" DefaultAddress = "localhost:46753" )
Variables ¶
This section is empty.
Functions ¶
Types ¶
type AccessRequest ¶
type AccessRequest struct {
httprequest.Route `httprequest:"POST /macaroon"`
Password string `httprequest:"password,form"`
}
type AccessResponse ¶
type Error ¶
type Error struct {
Message string `json:"message,omitempty"`
Code ErrorCode `json:"code,omitempty"`
}
Error represents an error - it is returned for any response that fails.
type ErrorCode ¶
type ErrorCode string
ErrorCode holds the class of an error in machine-readable format. It is also an error in its own right.
type FindRootKeyRequest ¶
type FindRootKeyRequest struct {
httprequest.Route `httprequest:"GET /key/:Id"`
Id string `httprequest:",path"`
}
type FindRootKeyResponse ¶
type FindRootKeyResponse struct {
RootKey []byte `json:"rootKey"`
}
type NewRootKeyRequest ¶
type NewRootKeyRequest struct {
httprequest.Route `httprequest:"POST /key"`
}
type NewRootKeyResponse ¶
type SetPasswordRequest ¶
type SetPasswordRequest struct {
httprequest.Route `httprequest:"PUT /password"`
OldPassword string `httprequest:"oldPassword,form"`
NewPassword string `httprequest:"newPassword,form"`
}
Click to show internal directories.
Click to hide internal directories.